==> commons-vfs-2.4-src.zip: commons-vfs-2.4/commons-vfs2-examples/src/main/java/org/apache/commons/vfs2/example/filter/PrefixFileFilterExample.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.vfs2.example.filter;

import java.io.File;

import org.apache.commons.vfs2.FileFilterSelector;
import org.apache.commons.vfs2.FileObject;
import org.apache.commons.vfs2.FileSystemManager;
import org.apache.commons.vfs2.VFS;
import org.apache.commons.vfs2.filter.PrefixFileFilter;

/**
 * Example for using {@link PrefixFileFilter}.
 */
// CHECKSTYLE:OFF Example code
public class PrefixFileFilterExample {

    public static void main(String[] args) throws Exception {

        // Example, to print all files and directories in the current directory
        // whose name starts with a <code>.</code>
        FileSystemManager fsManager = VFS.getManager();
        FileObject dir = fsManager.toFileObject(new File("."));
        FileObject[] files = dir.findFiles(new FileFilterSelector(new PrefixFileFilter(".")));
        for (int i = 0; i < files.length; i++) {
            System.out.println(files[i]);
        }

    }

}
// CHECKSTYLE:ON

==> commons-vfs-2.10.0-src.zip: commons-vfs-2.10.0/commons-vfs2-examples/src/main/java/org/apache/commons/vfs2/example/filter/PrefixFileFilterExample.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.commons.vfs2.example.filter;

import java.io.File;

import org.apache.commons.vfs2.FileFilterSelector;
import org.apache.commons.vfs2.FileObject;
import org.apache.commons.vfs2.FileSystemManager;
import org.apache.commons.vfs2.VFS;
import org.apache.commons.vfs2.filter.PrefixFileFilter;

/**
 * Example for using {@link PrefixFileFilter}.
 */
// CHECKSTYLE:OFF Example code
public final class PrefixFileFilterExample {
    /**
     * Invokes this example from the command line.
     *
     * @param args Arguments TODO
     * @throws Exception If anything goes wrong.
     */
    public static void main(final String[] args) throws Exception {

        // Example, to print all files and directories in the current directory
        // whose name starts with a {@code .}
        final FileSystemManager fsManager = VFS.getManager();
        final FileObject dir = fsManager.toFileObject(new File("."));
        final FileObject[] files = dir.findFiles(new FileFilterSelector(new PrefixFileFilter(".")));
        for (final FileObject file : files) {
            System.out.println(file);
        }

    }

    private PrefixFileFilterExample() {
        /* main class not instantiated. */
    }

}
// CHECKSTYLE:ON
